package WebService::PayPal::PaymentsAdvanced::Role::ClassFor;
$WebService::PayPal::PaymentsAdvanced::Role::ClassFor::VERSION = '0.000007';
use Moo::Role;

sub _class_for {
    my $self = shift;
    return 'WebService::PayPal::PaymentsAdvanced::' . shift;
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

WebService::PayPal::PaymentsAdvanced::Role::ClassFor

=head1 VERSION

version 0.000007

=head1 AUTHOR

Olaf Alders <olaf@wundercounter.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by MaxMind, Inc..

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
