
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.039.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "A simple wrapper around the PayPal Payments Advanced web service",
  "dist_author" => [
    "Olaf Alders <olaf\@wundercounter.com>"
  ],
  "dist_name" => "WebService-PayPal-PaymentsAdvanced",
  "dist_version" => "0.000007",
  "license" => "artistic_2",
  "module_name" => "WebService::PayPal::PaymentsAdvanced",
  "recursive_test_files" => 1,
  "requires" => {
    "Data::GUID" => 0,
    "DateTime" => 0,
    "DateTime::Format::MySQL" => 0,
    "DateTime::TimeZone" => 0,
    "HTTP::Message::PSGI" => 0,
    "LWP::Protocol::https" => 0,
    "LWP::UserAgent" => 0,
    "List::AllUtils" => 0,
    "Mojolicious::Lite" => 0,
    "Moo" => "1.004005",
    "Moo::Role" => 0,
    "MooX::HandlesVia" => 0,
    "MooX::StrictConstructor" => 0,
    "Test::LWP::UserAgent" => 0,
    "Throwable::Error" => 0,
    "Type::Params" => 0,
    "Types::Common::Numeric" => 0,
    "Types::Standard" => 0,
    "Types::URI" => 0,
    "URI" => 0,
    "URI::FromHash" => 0,
    "URI::QueryParam" => 0,
    "Web::Scraper" => 0,
    "feature" => 0,
    "perl" => "5.014"
  },
  "script_files" => [
    "bin/mock-payflow-link",
    "bin/mock-payflow-pro"
  ],
  "test_requires" => {
    "HTTP::Response" => 0,
    "LWP::ConsoleLogger::Easy" => 0,
    "Mozilla::CA" => 20130114,
    "Path::Tiny" => 0,
    "Scalar::Util" => 0,
    "Test::Fatal" => 0,
    "Test::More" => 0,
    "Test::RequiresInternet" => 0,
    "Try::Tiny" => 0,
    "lib" => 0,
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "HTTP::Response" => 0,
  "LWP::ConsoleLogger::Easy" => 0,
  "Module::Build" => "0.28",
  "Mozilla::CA" => 20130114,
  "Path::Tiny" => 0,
  "Scalar::Util" => 0,
  "Test::Fatal" => 0,
  "Test::More" => 0,
  "Test::RequiresInternet" => 0,
  "Try::Tiny" => 0,
  "lib" => 0,
  "strict" => 0,
  "warnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
